Module batch

Module batch 

Functions

delete_many
Delete the key-value pairs associated with the keys in the store.
get_many
Get the key-value pairs associated with the keys in the store. It returns a list of key-value pairs.
set_many
Set the values associated with the keys in the store. If the key already exists in the store, it overwrites the value.

Type Aliases

Bucket
Error