Functions
- delete_
many - Delete the key-value pairs associated with the keys in the store.
- get_
many - Get the key-value pairs associated with the keys in the store. It returns a list of key-value pairs.
- set_
many - Set the values associated with the keys in the store. If the key already exists in the store, it overwrites the value.