Structs
- Bucket
- A bucket is a collection of key-value pairs. Each key-value pair is stored as a entry in the bucket, and the bucket itself acts as a collection of all these entries.
- KeyResponse
- A response to a
list-keysoperation.
Enums
- Error
- The set of errors which may be raised by functions in this package
Functions
- open
- Get the bucket with the specified identifier.